summaryrefslogtreecommitdiff
path: root/yaffs_mtdif1_single.c
diff options
context:
space:
mode:
authorCharles Manning <cdhmanning@gmail.com>2011-02-01 10:57:18 +1300
committerCharles Manning <cdhmanning@gmail.com>2011-02-01 10:57:18 +1300
commit6500cebaa2c93512d544719956af259ca13f83b7 (patch)
treeaab99283b974185ddf521defbad25b81779b684c /yaffs_mtdif1_single.c
parent6120ba5a0a029e945f4a2e7e5955896f112d4adc (diff)
yaffs: Clean up as per Ryan's comments
Clean up a whole lot of code issues raised by Ryan. Some further reformatting etc to be mor kernel friendly. Signed-off-by: Charles Manning <cdhmanning@gmail.com>
Diffstat (limited to 'yaffs_mtdif1_single.c')
-rw-r--r--yaffs_mtdif1_single.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/yaffs_mtdif1_single.c b/yaffs_mtdif1_single.c
index 182870c..d82f4d7 100644
--- a/yaffs_mtdif1_single.c
+++ b/yaffs_mtdif1_single.c
@@ -283,7 +283,7 @@ static int nandmtd1_test_prerequists(struct mtd_info *mtd)
*
* Examine the tags of the first chunk of the block and return the state:
* - YAFFS_BLOCK_STATE_DEAD, the block is marked bad
* - YAFFS_BLOCK_STATE_NEEDS_SCANNING, the block is in use
* - YAFFS_BLOCK_STATE_EMPTY, the block is clean
*
* Always returns YAFFS_OK.
@@ -313,9 +313,9 @@ int nandmtd1_query_block(struct yaffs_dev *dev, int block_no,
state = YAFFS_BLOCK_STATE_DEAD;
} else if (etags.ecc_result != YAFFS_ECC_RESULT_NO_ERROR) {
/* bad tags, need to look more closely */
- state = YAFFS_BLOCK_STATE_NEEDS_SCANNING;
+ state = YAFFS_BLOCK_STATE_NEEDS_SCAN;
} else if (etags.chunk_used) {
- state = YAFFS_BLOCK_STATE_NEEDS_SCANNING;
+ state = YAFFS_BLOCK_STATE_NEEDS_SCAN;
seqnum = etags.seq_number;
} else {
state = YAFFS_BLOCK_STATE_EMPTY;
@@ -283,7 +283,7 @@ static int nandmtd1_test_prerequists(struct mtd_info *mtd)
* Examine the tags of the first chunk of the block and return the state:
* - YAFFS_BLOCK_STATE_DEAD, the block is marked bad
- * - YAFFS_BLOCK_STATE_NEEDS_SCANNING, the block is in use
+ * - YAFFS_BLOCK_STATE_NEEDS_SCAN, the block is in use
* - YAFFS_BLOCK_STATE_EMPTY, the block is clean
*